aboutsummaryrefslogtreecommitdiffstats
path: root/engine/items/tm_prices.asm
diff options
context:
space:
mode:
Diffstat (limited to 'engine/items/tm_prices.asm')
-rw-r--r--engine/items/tm_prices.asm4
1 files changed, 2 insertions, 2 deletions
diff --git a/engine/items/tm_prices.asm b/engine/items/tm_prices.asm
index df9761bd..8e64e5d0 100644
--- a/engine/items/tm_prices.asm
+++ b/engine/items/tm_prices.asm
@@ -1,7 +1,7 @@
GetMachinePrice::
; Input: [wcf91] = Item Id of a TM
; Output: Stores the TM price at hItemPrice
- ld a, [wcf91] ; a contains TM item id
+ ld a, [wCurItem]
sub TM01 ; underflows below 0 for HM items (before TM items)
ret c ; HMs are priceless
ld d, a
@@ -1,7 +1,7 @@
GetMachinePrice::
-; Input: [wcf91] = Item Id of a TM
+; Input: [wCurItem] = Item ID of a TM
; Output: Stores the TM price at hItemPrice